@@ -2,7 +2,7 @@
 __author__ = 'Laurent P. René de Cotret'
 __email__ = 'laurent.renedecotret@mail.mcgill.ca'
 __license__ = 'MIT'
-__version__ = '0.4.10' # TODO: automatic versioning?
+__version__ = '0.4.11' # TODO: automatic versioning?
 
 from .affine import (affine_map, change_basis_mesh, change_of_basis, is_basis,
                      is_rotation_matrix, minimum_image_distance,
@@ -20,5 +20,5 @@ from .image import (align, azimuthal_average, combine_masks, diff_register,
 from .plot_utils import rgb_sweep, spectrum_colors
 from .simulation import (affe, bounded_reflections, electrostatic,
                          pelectrostatic, powdersim, structure_factor)
-from .structure import Atom, Crystal, Lattice
+from .structure import Atom, Crystal, Lattice, symmetry_expansion
 from .voigt import gaussian, lorentzian, pseudo_voigt
