@@ -5,4 +5,4 @@ from .alignment import align, diff_register, ialign, shift_image
 from .correlation import mnxc2
 from .metrics import snr_from_collection, isnr, mask_from_collection, combine_masks, mask_image, trimr, triml
 from .powder import angular_average, azimuthal_average, powder_center
-from .symmetry import nfold, nfold_symmetry
+from .symmetry import nfold
