@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from .. import powdersim
-from ...structure import graphite
+from ... import Crystal
 from copy import deepcopy
 import numpy as np
 import unittest
@@ -9,7 +9,7 @@ class TestPowdersim(unittest.TestCase):
 
 	def setUp(self):
 		self.scattering_length = np.linspace(0.11, 0.8, 200)
-		self.crystal = deepcopy(graphite)
+		self.crystal = Crystal.from_database('C')
 
 	def test_return_shape(self):
 		""" Test that the return shape of powdersim() is as expected """
